summaryrefslogtreecommitdiffstats
path: root/src/Iterator/IteratorSortBy.php
diff options
context:
space:
mode:
Diffstat (limited to 'src/Iterator/IteratorSortBy.php')
-rw-r--r--src/Iterator/IteratorSortBy.php12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/Iterator/IteratorSortBy.php b/src/Iterator/IteratorSortBy.php
index c26e85c..0a0a604 100644
--- a/src/Iterator/IteratorSortBy.php
+++ b/src/Iterator/IteratorSortBy.php
@@ -1,13 +1,13 @@
<?php
/**
* Bakame.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>
* @copyright 2014 Ignace Nyamagana Butera
-* @link https://github.com/nyamsprod/Bakame.csv
+* @link https://github.com/nyamsprod/League.csv
* @license http://opensource.org/licenses/MIT
-* @version 4.2.1
-* @package Bakame.csv
+* @version 5.0.0
+* @package League.csv
*
* MIT LICENSE
*
@@ -30,7 +30,7 @@
* OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
* WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
-namespace Bakame\Csv\Iterator;
+namespace League\Csv\Iterator;
use Iterator;
use ArrayIterator;
@@ -38,7 +38,7 @@ use ArrayIterator;
/**
* A Trait to sort an Iterator
*
- * @package Bakame.csv
+ * @package League.csv
* @since 4.2.1
*
*/
@@ -1,13 +1,13 @@
<?php
/**
-* Bakame.csv - A lightweight CSV Coder/Decoder library
+* League.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>